@@ -142,7 +142,7 @@ del nugent_subclass_cc
 # -----------------------------------------------------------------------
 # Sako et al 2011 models
 
-s11_baseurl = 'http://kbarbary.github.com/data/models/'
+s11_baseurl = 'http://kbarbary.github.io/data/models/'
 s11_ref = ('S11', 'Sako et al. 2011 '
            '<http://adsabs.harvard.edu/abs/2011ApJ...738..162S>')
 s11_website = 'http://sdssdp62.fnal.gov/sdsssn/SNANA-PUBLIC/'
@@ -219,7 +219,7 @@ def load_stretchmodel_fits(remote_url, name=None, version=None):
     set_bandfluxerror_sn1a(model)
     return model
 
-hsiao_baseurl = 'http://kbarbary.github.com/data/models/'
+hsiao_baseurl = 'http://kbarbary.github.io/data/models/'
 hsiao_website = 'http://csp.obs.carnegiescience.edu/data/snpy'
 hsiao_subclass = '`~sncosmo.StretchModel`'
 hsiao_ref = ('H07', 'Hsiao et al. 2007 <http://adsabs.harvard.edu/abs/'
@@ -264,6 +264,7 @@ def load_salt2model(remote_url, topdir, name=None, version=None):
         v00file=t.extractfile(join(topdir,'salt2_spec_variance_0.dat')),
         v11file=t.extractfile(join(topdir,'salt2_spec_variance_1.dat')),
         v01file=t.extractfile(join(topdir,'salt2_spec_covariance_01.dat')),
+        clfile=t.extractfile(join(topdir,'salt2_color_correction.dat')),
         errscalefile=errscalefile, name=name, version=version)
     t.close()
     set_bandfluxerror_sn1a(model)
@@ -286,6 +287,17 @@ registry.register_loader(
     version='2.0', type='SN Ia', subclass='`~sncosmo.SALT2Model`', 
     url=salt2_website, reference=salt2_2_reference)
 
+# --------------------------------------------------------------------------
+# SALT2 extended
+salt2ext_url = 'http://kbarbary.github.io/data/models/salt2_extended.tar.gz'
+salt2ext_website = 'http://sdssdp62.fnal.gov/sdsssn/SNANA-PUBLIC/'
+salt2ext_note = "extracted from SNANA's SNDATA_ROOT on 15 August 2013."
+
+registry.register_loader(
+    Model, 'salt2-extended', load_salt2model, [salt2ext_url, 'salt2_extended'],
+    version='1.0', type='SN Ia', subclass='`~sncosmo.SALT2Model`', 
+    url=salt2ext_website, note=salt2ext_note)
+
 # --------------------------------------------------------------------------
 # 2011fe
 
