@@ -27,11 +27,13 @@ def plot_lc(data=None, model=None, bands=None, show_pulls=True,
     ----------
     data : `~numpy.ndarray` or dict of list_like, optional
         Structured array or dictionary of arrays or lists.
-    model : `~sncosmo.Model`, optional
-        If given, model light curve is plotted.
+    model : `~sncosmo.Model`, str or list, optional
+        If given, model light curve is plotted. If a string, the corresponding
+        model is fetched from the registry. If a list of `sncosmo.Model` or
+        string, multiple models are plotted.
     fname : str, optional
-        Filename to write plot to. If `None` (default), plot is shown using
-        ``show()``.
+        Filename to write plot to. If `None` (default), plot is not saved to
+        file, but Figure object is still returned.
     bands : list, optional
         List of Bandpasses, or names thereof, to plot.
     show_pulls : bool, optional
@@ -48,14 +50,19 @@ def plot_lc(data=None, model=None, bands=None, show_pulls=True,
         placed in a separate "column". Use newline separators for multiple
         lines.
     figtext_ysize : float, optional
-        Space to reserve at top of figure for figtext (if not None). Default is
-        1 inch.
+        Space to reserve at top of figure for figtext (if not None).
+        Default is 1 inch.
     xfigsize, yfigsize : float, optional
         figure size in inches in x or y. Specify one or the other, not both.
         Default is xfigsize=8.
     dpi : float, optional
-        dpi to pass to ``plt.savefig()`` for rasterized images. 
-        
+        dpi parameter to pass to ``savefig()``, when fname is given.
+
+    Returns
+    -------
+    fig : `~matplotlib.pyplot.Figure`
+        Figure object containing the plot. 
+
     Examples
     --------
 
@@ -71,13 +78,32 @@ def plot_lc(data=None, model=None, bands=None, show_pulls=True,
     
         >>> model = sncosmo.get_model('salt2')
         >>> model.set(z=0.5, c=0.2, t0=55100., mabs=-19.5, x1=0.5)
-        >>> sncosmo.plot_lc(data, model=model)
+        >>> sncosmo.plot_lc(data, model=model, fname='output.png')
 
     .. image:: /pyplots/plotlc_example.png
 
     Plot just the model, for selected bands::
 
-        >>> sncosmo.plot_lc(model=model, bands=['sdssg', 'sdssr', 'sdssi', 'sdssz'])
+        >>> sncosmo.plot_lc(model=model,
+        ...                 bands=['sdssg', 'sdssr', 'sdssi', 'sdssz'],
+        ...                 fname='output.png')
+
+    Show the plot::
+
+        >>> from matplotlib import pyplot as plt
+        >>> sncosmo.plot_lc(data)
+        >>> plt.show()
+
+    Plot figures on a multipage pdf::
+
+        >>> from matplotlib.backends.backend_pdf import PdfPages
+        >>> pp = PdfPages('output.pdf')
+        >>> 
+        >>> # Do the following as many times as you like:
+        >>> fig = sncosmo.plot_lc(data)
+        >>> pp.savefig(fig)
+        >>>
+        >>> pp.close()  # don't forget to close at the end!
 
     """
 
@@ -93,9 +119,18 @@ def plot_lc(data=None, model=None, bands=None, show_pulls=True,
         raise ValueError('must specify at least one of: data, model')
     if data is None and bands is None:
         raise ValueError('must specify bands to plot for model')
-    if model is not None:
-        model = get_model(model)
 
+    # Get the model(s).
+    if model is not None:
+        if isinstance(model, basestring) or not isiterable(model):
+            models = [model]
+        else:
+            models = model
+        models = [get_model(m) for m in models]
+    else:
+        models = []
+
+    # Standardize and normalize data.
     if data is not None:
         data = standardize_data(data)
         data = normalize_data(data, zp=zp, zpsys=zpsys)
@@ -118,6 +153,9 @@ def plot_lc(data=None, model=None, bands=None, show_pulls=True,
     if offsets is not None:
         for key, value in offsets.iteritems():
             offsets[get_bandpass(key)] = offsets.pop(key)
+        for band in bands:
+            if band not in offsets:
+                offsets[band] = 0.
 
     # Calculate layout of figure (columns, rows, figure size)
     nsubplots = len(bands)
@@ -150,7 +188,6 @@ def plot_lc(data=None, model=None, bands=None, show_pulls=True,
             t = fig.text(xpos, 0.95, figtext[i],
                          va="top", ha="left", multialignment="left")
 
-
     # Loop over bands.
     axnum = 0
     for disp, band in sorted(zip(disps, bands)):
@@ -160,72 +197,97 @@ def plot_lc(data=None, model=None, bands=None, show_pulls=True,
                      (cm_disp_range[1] - cm_disp_range[0]))
 
         ax = plt.subplot(nrow, ncol, axnum)
-        plt.text(0.9, 0.9, band.name, color='k', ha='right', va='top',
-                 transform=ax.transAxes)
         if axnum % 2:
             plt.ylabel('flux ($ZP_{' + get_magsystem(zpsys).name.upper() +
                        '} = ' + str(zp) + '$)')
 
         xlabel_text = 'time'
-        if model is not None and model.params['t0'] != 0.:
-            xlabel_text += ' - {:.2f}'.format(model.params['t0'])
+        if len(models) > 0 and models[0].params['t0'] != 0.:
+            xlabel_text += ' - {:.2f}'.format(models[0].params['t0'])
 
+        # Plot data if there is any.
         if data is not None:
             idx = data_bands == band
             time = data['time'][idx]
             flux = data['flux'][idx]
             fluxerr = data['fluxerr'][idx]
 
-            if model is None:
+            if len(models) == 0:
                 plotted_time = time
             else:
-                plotted_time = time - model.params['t0']
+                plotted_time = time - models[0].params['t0']
 
             plt.errorbar(plotted_time, flux, fluxerr, ls='None',
                          color=color, marker='.', markersize=3.)
 
-        if (model is not None and model.bandoverlap(band) and
-            (offsets is None or band in offsets)):
+        # Plot model(s) if there are any.
+        if len(models) > 0:
 
-            plotted_time = model.times() - model.params['t0']
+            linestyles = ['-', '--', ':', '-.']
+            for i, model in enumerate(models):
+                if not model.bandoverlap(band):
+                    continue
 
-            if include_model_error:
-                mflux, mfluxerr = model.bandflux(band, zp=zp, zpsys=zpsys,
-                                                 include_error=True)
-            else:
-                mflux = model.bandflux(band, zp=zp, zpsys=zpsys,
-                                       include_error=False)
+                plotted_time = model.times() - models[0].params['t0']
 
-            if offsets is not None:
-                mflux = mflux + offsets[band]
+                if include_model_error:
+                    mflux, mfluxerr = model.bandflux(band, zp=zp, zpsys=zpsys,
+                                                     include_error=True)
+                else:
+                    mflux = model.bandflux(band, zp=zp, zpsys=zpsys,
+                                           include_error=False)
 
-            plt.plot(plotted_time, mflux, ls='-', marker='None', color=color)
-            if include_model_error:
-                plt.fill_between(plotted_time, mflux - mfluxerr,
-                                 mflux + mfluxerr, color=color,
-                                 alpha=0.2)
+                if offsets is not None and band in offsets:
+                    mflux = mflux + offsets[band]
+
+                plt.plot(plotted_time, mflux, ls=linestyles[i%len(linestyles)],
+                         marker='None', color=color, label=model.name)
+                if include_model_error:
+                    plt.fill_between(plotted_time, mflux - mfluxerr,
+                                     mflux + mfluxerr, color=color,
+                                     alpha=0.2)
+
+                if i == 0:
+                    mflux_min, mflux_max = mflux.min(), mflux.max()
+                else:
+                    mflux_min = min(mflux_min, mflux.min())
+                    mflux_max = max(mflux_max, mflux.max())
 
             # maximum plot range
             ymin, ymax = ax.get_ylim()
-            mflux_min, mflux_max = mflux.min(), mflux.max()
             ymax = min(ymax, 2. * mflux_max)
             ymin = max(ymin, mflux_min - (ymax - mflux_max))
             ax.set_ylim(ymin, ymax)
 
+            # Add a legend, if this is the first axes and there are two
+            # or more models to distinguish between.
+            if axnum == 1 and len(models) >= 2:
+                leg = plt.legend(loc='upper right',
+                                 fontsize='small', frameon=True)
+
+        # Band name in corner: upper right if there is no legend, otherwise
+        # upper left.
+        if (axnum == 1 and len(models) > 1):
+            plt.text(0.08, 0.92, band.name, color='k', ha='left', va='top',
+                     transform=ax.transAxes)
+        else:
+            plt.text(0.92, 0.92, band.name, color='k', ha='right', va='top',
+                     transform=ax.transAxes)
+
         # plot a horizontal line at flux=0.
         ax.axhline(y=0., ls='--', c='k')
 
         # steal part of the axes and plot pulls
-        if (show_pulls and data is not None and model is not None and
-            model.bandoverlap(band) and (offsets is None or band in offsets)):
+        if (show_pulls and data is not None and len(models) == 1 and
+            models[0].bandoverlap(band)):
             divider = make_axes_locatable(ax)
             axpulls = divider.append_axes("bottom", size=0.7, pad=0.1,
                                           sharex=ax)
-            mflux = model.bandflux(band, time, zp=zp, zpsys=zpsys) 
-            if offsets is not None:
+            mflux = models[0].bandflux(band, time, zp=zp, zpsys=zpsys) 
+            if offsets is not None and band in offsets:
                 mflux = mflux + offsets[band]
             pulls = (flux - mflux) / fluxerr
-            plt.plot(time - model.params['t0'], pulls, marker='.',
+            plt.plot(time - models[0].params['t0'], pulls, marker='.',
                      markersize=5., color=color, ls='None')
             plt.axhline(y=0., color=color)
             plt.setp(ax.get_xticklabels(), visible=False)
@@ -238,11 +300,13 @@ def plot_lc(data=None, model=None, bands=None, show_pulls=True,
     plt.subplots_adjust(left=0.1, right=0.95,
                         bottom=0.1, top=0.97 - figtext_yfrac,
                         wspace=0.2, hspace=0.2)
-    if fname is None:
-        plt.show()
-    else:
+
+    if fname is not None:
         plt.savefig(fname, dpi=dpi)
-    plt.clf()
+        plt.clf()
+
+    return fig
+
 
 def pretty_value_and_error(value, error, latex=False):
     """Return a string representing value and error.
